<?php

/**
 * @file
 * Definition of WoW\RemoteEntityControllerInterface.
 */

interface WoWRemoteEntityControllerInterface
  extends EntityAPIControllerInterface {

  /**
   * Fetch a remote resource from the service.
   *
   * @param WoWRemoteEntity $entity
   *   The entity to fetch.
   * @param array $query
   *   (Optional) An array of query key/value-pairs (without any URL-encoding) to
   *   append to the URL.
   *   - locale: You can specify your own locale here.
   *     It it the responsibility of the caller to pass a valid locale.
   *     @see wow_api_locale()
   * @param array $options
   *   (Optional) An array that can have one or more of the following elements:
   *   - headers: An array containing request headers to send as name/value pairs.
   *   - method: A string containing the request method. Defaults to 'GET'.
   *   - data: A string containing the request body, formatted as
   *     'param=value&param=value&...'. Defaults to NULL.
   *   - max_redirects: An integer representing how many times a redirect
   *     may be followed. Defaults to 3.
   *   - timeout: A float representing the maximum number of seconds the function
   *     call may take. The default is 30 seconds. If a timeout occurs, the error
   *     code is set to the HTTP_REQUEST_TIMEOUT constant.
   *   - context: A context resource created with stream_context_create().
   * @param Boolean $catch
   *   Whether to catch exceptions or not.
   *
   * @return WoWRemoteEntity
   */
  public function fetch($entity, array $query = array(), array $options = array(), $catch = TRUE);

  /**
   * Process a HttpResponse from the service.
   *
   * @param WoWRemoteEntity $entity
   *   The entity being working on.
   * @param WoWHttpResponse $response
   *   The http response.
   * @param Boolean $catch
   *   Whether to catch exceptions or not.
   *
   * @return WoWRemoteEntity
   */
  public function process($entity, $response, $catch = TRUE);

}
